<?php  if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Display KB configuration Wizard
 *
 * @copyright   Copyright (C) 2018, Echo Plugins
 * @license http://opensource.org/licenses/gpl-2.0.php GNU Public License
 */
class EPKB_KB_Wizard_Cntrl {

	function __construct() {
		add_action( 'wp_ajax_epkb_apply_wizard_changes', array( $this, 'apply_wizard_changes' ) );
	}

	public function apply_wizard_changes() {

		// verify that request is authentic
		if ( empty( $_REQUEST['_wpnonce_apply_wizard_changes'] ) || ! wp_verify_nonce( $_REQUEST['_wpnonce_apply_wizard_changes'], '_wpnonce_apply_wizard_changes' ) ) {
			EPKB_Utilities::ajax_show_error_die( __( 'You do not have permission to edit this knowledge base', 'echo-knowledge-base' ) );
		}

		// ensure that user has correct permissions
		if ( ! is_admin() || ! current_user_can( 'manage_options' ) ) {
			EPKB_Utilities::ajax_show_error_die( __( 'You do not have permission to edit this knowledge base', 'echo-knowledge-base' ) );
		}

		// get new KB config
		$new_config = EPKB_Utilities::post('kb_config', array());
		if ( empty($new_config) || count($new_config) < 100 ) {
			EPKB_Utilities::ajax_show_error_die( __( 'Invalid parameters (1). Please refresh your page', 'echo-knowledge-base' ) );
		}

		// remove unused fields
		unset($new_config['theme_desc']);
		unset($new_config['undefined']);
		unset($new_config['kb_id']);

		// get current KB ID
		$wizard_kb_id = EPKB_Utilities::post('epkb_wizard_kb_id');
		if ( empty($wizard_kb_id) || ! EPKB_Utilities::is_positive_int( $wizard_kb_id ) ) {
			EPKB_Utilities::ajax_show_error_die( __( 'Invalid parameters (2). Please refresh your page', 'echo-knowledge-base' ) );
		}

		$is_blank_kb = EPKB_Utilities::is_blank_KB( $wizard_kb_id );
		if ( is_wp_error($is_blank_kb) ) {
			EPKB_Utilities::ajax_show_error_die( __( 'Could not load KB config (3). Please contact us.', 'echo-knowledge-base' ) );
		}

		// get and sanitize KB name
		$kb_name = EPKB_Utilities::post('kb_name');
		$kb_name = empty($kb_name) ? '' : substr( $kb_name, 0, 50 );
		$kb_name = sanitize_text_field($kb_name);
		if ( empty($kb_name) ) {
			EPKB_Utilities::ajax_show_error_die( __( 'Invalid parameters (3). Please refresh your page', 'echo-knowledge-base' ) );
		}

		// get KB slug
		$kb_slug = EPKB_Utilities::post('kb_slug');
		$kb_slug = empty($kb_slug) ? '' : substr( $kb_slug, 0, 100 );
		$kb_slug = sanitize_title($kb_slug);
		if ( $is_blank_kb && empty($kb_slug) ) {
			EPKB_Utilities::ajax_show_error_die( __( 'Invalid parameters (4). Please refresh your page', 'echo-knowledge-base' ) );
		}

		// do we need to create a new KB content?
		$message = '';
		if ( $is_blank_kb ) {

			// 1. save KB configuration based on Wizard changes
			$new_config['status'] = EPKB_KB_Status::BLANK;
			$orig_config = EPKB_KB_Config_Specs::get_default_kb_config( $wizard_kb_id );
			$orig_config['status'] = EPKB_KB_Status::BLANK;
			$udpate_kb_msg = $this->update_kb_configuration( $wizard_kb_id, $orig_config, $new_config );
			if ( ! empty($udpate_kb_msg) ) {
				EPKB_Utilities::ajax_show_error_die( __( 'Error occurred. Could not create KB (34)', 'echo-knowledge-base' ) );
			}

			// 2. add sample content and Main Page
			$new_config = EPKB_KB_Handler::add_new_knowledge_base( $wizard_kb_id, $kb_name, $kb_slug );
			if ( is_wp_error($new_config) ) {
				EPKB_Utilities::ajax_show_error_die( __( 'Could not create a new knowledge base (add option failed). Please contact us so that we can help you <a href="https://www.echoknowledgebase.com/technical-support/" target="_blank">here</a>', 'echo-knowledge-base' ) );
			}

			// Clear permalinks
			update_option( 'epkb_flush_rewrite_rules', true );
			flush_rewrite_rules( false );

		} else {

			// original or default KB if none exists yet
			$orig_config = epkb_get_instance()->kb_config_obj->get_kb_config( $wizard_kb_id );
			if ( is_wp_error( $orig_config ) ) {
				EPKB_Utilities::ajax_show_error_die( __( 'Error occurred. Please contact us. (8)', 'echo-knowledge-base' ) );
			}

			// prevent new config to overwrite essential fields
			$new_config['id'] = $orig_config['id'];
			$new_config['status'] = $orig_config['status'];
			$new_config['kb_name'] = $kb_name;
			$new_config['kb_main_pages'] = $orig_config['kb_main_pages'];
			$new_config['kb_articles_common_path'] = $orig_config['kb_articles_common_path']; //$is_existing_kb ? $orig_config['kb_articles_common_path'] : $kb_slug;
			$new_config['templates_for_kb'] = $orig_config['templates_for_kb'];
			$new_config['wpml_is_enabled'] = $orig_config['wpml_is_enabled'];
			$new_config['templates_for_kb_category_archive_page_heading_description'] = $orig_config['templates_for_kb_category_archive_page_heading_description'];
			$new_config['search_title'] = $orig_config['search_title'];

			// only save settings if any have changed
			$changed_config = EPKB_KB_Wizard::get_changed_config( $orig_config, $new_config );
			if ( empty($changed_config) ) {
				$message = 'nothing has changed';

			} else {
				$message = $changed_config;

				$udpate_kb_msg = $this->update_kb_configuration( $orig_config['id'], $orig_config, $new_config );
				if ( ! empty($udpate_kb_msg) ) {
					EPKB_Utilities::ajax_show_error_die( __( 'Error occurred. Could not update KB (33)', 'echo-knowledge-base' ) );
				}
			}
		}

		wp_die( json_encode( array( 'message' => '', /** DEBUG $message, */ 'kb_main_page_link' => EPKB_KB_Handler::get_first_kb_main_page_url( $new_config ) ) ) );
	}

	/**
	 * Triggered when user submits changes to KB configuration
	 *
	 * @param $kb_id
	 * @param $orig_config
	 * @param $new_config
	 * @return string
	 */
	public function update_kb_configuration( $kb_id, $orig_config, $new_config ) {

		// core handles only default KB
		if ( $kb_id != EPKB_KB_Config_DB::DEFAULT_KB_ID && ! defined( 'E' . 'MKB_PLUGIN_NAME' ) ) {
			return 'Ensure that Multiple KB add-on is active and refresh this page';
		}

		// retrieve user input
		$field_specs = EPKB_KB_Config_Specs::get_fields_specification( $kb_id );
		$form_fields = EPKB_Utilities::retrieve_and_sanitize_form( $new_config, $field_specs );
		if ( empty($form_fields) ) {
			EPKB_Logging::add_log("form fields missing");
			return __( 'Form fields missing. Please refresh your browser', 'echo-knowledge-base' );
		} else if ( count($form_fields) < 100 ) {
			return __( 'Some form fields are missing. Please refresh your browser and try again or contact support', 'echo-knowledge-base' );
		}

		$input_handler = new EPKB_Input_Filter();
		$new_kb_config = $input_handler->retrieve_and_sanitize_form_fields( $form_fields, $field_specs, $orig_config );

		// verify correct Article Page layout based on Main Page layout
		$article_page_layouts = EPKB_KB_Config_Layouts::get_article_page_layouts( $new_kb_config['kb_main_page_layout'] );
		if ( empty($article_page_layouts) ) {
			$new_kb_config['kb_article_page_layout'] = EPKB_KB_Config_Layouts::KB_ARTICLE_PAGE_NO_LAYOUT;
		} else if ( ! in_array( $new_kb_config['kb_article_page_layout'], array_keys($article_page_layouts) ) ) {
			$article_pg_layouts = array_keys($article_page_layouts);
			$new_kb_config['kb_article_page_layout'] = $article_pg_layouts[0];
		}

		// ensure kb id and WPML is preserved
		$new_kb_config['id'] = $kb_id;
		$new_kb_config['wpml_is_enabled'] = $orig_config['wpml_is_enabled'];

		// sanitize and save configuration in the database. see EPKB_Settings_DB class
		$result = epkb_get_instance()->kb_config_obj->update_kb_configuration( $kb_id, $new_kb_config );
		if ( is_wp_error( $result ) ) {
			/* @var $result WP_Error */
			$message = $result->get_error_data();
			if ( empty($message) ) {
				return __( 'Could not save the new configuration (3)', 'echo-knowledge-base' );
			} else {
				return __( 'Configuration NOT saved (4) due to following problems:', 'echo-knowledge-base' );
			}
		}

		// in case user changed article common path, flush the rules
		EPKB_Articles_CPT_Setup::register_custom_post_type( $new_kb_config, $kb_id );

		// always flush the rules; this will ensure that proper rewrite rules for layouts with article visible will be added
		flush_rewrite_rules( false );
		update_option('epkb_flush_rewrite_rules', true);

		// we are done here
		return '';
	}
}
