<?php  if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Store Wizard theme data
 *
 * @copyright   Copyright (C) 2018, Echo Plugins
 * @license http://opensource.org/licenses/gpl-2.0.php GNU Public License
 */
class EPKB_KB_Wizard_Themes {

	public static function get_all_themes() {
		$all_themes = array();
		$all_themes[0] = self::get_theme( 0 );
		$all_themes[1] = self::get_theme( 1 );
		$all_themes[2] = self::get_theme( 2 );
		$all_themes[3] = self::get_theme( 3 );
		$all_themes[4] = self::get_theme( 4 );
		$all_themes[5] = self::get_theme( 5 );
		$all_themes[6] = self::get_theme( 6 );
		$all_themes[7] = self::get_theme( 7 );
		$all_themes[8] = self::get_theme( 8 );
		$all_themes[9] = self::get_theme( 9 );
		$all_themes[10] = self::get_theme( 10 );
		return $all_themes;
	}

	public static function get_theme_defaults() {

		$kb_defaults = EPKB_KB_Config_Specs::get_default_kb_config( EPKB_KB_Config_DB::DEFAULT_KB_ID );

		$template_defaults = array (
			'id'                                        => EPKB_KB_Config_DB::DEFAULT_KB_ID,
			'status'			                        => EPKB_KB_Status::PUBLISHED,
			'kb_main_pages'                             => array(),
			'kb_name'			                        => 'Default',
			'theme_desc'			                    => '',
			'categories_display_sequence'			    => 'user-sequenced',
			'nof_articles_displayed'			        => '3',
			'tab_nav_active_background_color'			=> '#F1F1F1',
			'tab_nav_active_font_color'			        => '#000000',
			'article_toc_media_3'                       => '500',
			'article_toc_position_from_top'             => '0',
			'article_toc_scroll_offset'                 => '0',
			'search_btn_border_color'			        => '#FFFFFF',
			'search_box_input_width'			        => '50',
			'search_box_padding_top'			        => '20',
			'search_box_padding_bottom'			        => '20',
			'breadcrumb_description_text'		        => '',
			'breadcrumb_padding_left'			        => '4',
			'breadcrumb_padding_right'			        => '4'
		);

		return array_merge($kb_defaults, $template_defaults);
	}

	/**
	 * Return specific theme.
	 *
	 * @param $theme_id
	 * @return array
	 */
	public static function get_theme( $theme_id ) {

		if ( ! EPKB_Utilities::is_positive_or_zero_int( $theme_id ) ) {
			return array();
		}

		switch ( $theme_id ) {
			
			case 0:
				// current theme configuration 
				$theme_config = epkb_get_instance()->kb_config_obj->get_current_kb_configuration();
				if ( is_wp_error( $theme_config ) ) {
					return array();
				}
				break;
			case 1:
				$theme_config = self::$theme_standard;
				break;
			case 2:
				$theme_config = self::$theme_organized;
				break;
			case 3:
				$theme_config = self::$theme_organized_2;
				break;
			case 4:
				$theme_config = self::$theme_spacious;
				break;
			case 5:
				$theme_config = self::$theme_informative;
				break;
			case 6:
				$theme_config = self::$theme_modern;
				break;
			case 7:
				$theme_config = self::$theme_bright;
				break;
			case 8:
				$theme_config = self::$theme_formal;
				break;
			case 9:
				$theme_config = self::$theme_disctinct;
				break;
			case 10:
				$theme_config = self::$theme_faqs;
				break;
			default:
				$theme_config = self::get_theme_defaults();
		}

		return array_merge(self::get_theme_defaults(), $theme_config);
	}
	
	/**
	 * Get JSON string with default theme data ready to use in html
	 *
	 * @param $theme_id
	 *
	 * @return string
	 */
	public static function get_theme_data( $theme_id ) {
		$theme = self::get_theme( $theme_id );
		return htmlspecialchars( json_encode( $theme ), ENT_QUOTES, 'UTF-8');
	}

	public static $theme_standard = array(
		'id'			                        => 1,
		'kb_name'			                    => 'Standard',
		'theme_desc'			                => 'Initial KB setup',
		'kb_articles_common_path'			    => 'knowledge-base-2',

		//General
		'background_color'                      =>  '#FFFFFF',

		//Search Box
		'search_title_font_color'               =>  '#FFFFFF',
		'search_background_color'               =>  '#f7941d',
		'search_text_input_background_color'    =>  '#FFFFFF',
		'search_text_input_border_color'        =>  '#CCCCCC',
		'search_btn_background_color'           =>  '#40474f',
		'search_btn_border_color'               =>  '#F1F1F1',

		//Articles Listed In Category Box
		'section_head_font_color'               =>  '#40474f',
		'section_head_background_color'         =>  '#FFFFFF',
		'section_head_description_font_color'   =>  '#b3b3b3',
		'section_body_background_color'         =>  '#FFFFFF',
		'section_border_color'                  =>  '#F7F7F7',
		'section_divider_color'                 =>  '#edf2f6',
		'section_category_font_color'           =>  '#40474f',
		'section_category_icon_color'           =>  '#f7941d',
		'section_head_category_icon_color'      =>  '#f7941d',
		'article_font_color'                    =>  '#459fed',
		'article_icon_color'                    =>  '#b3b3b3'
	);

	public static $theme_spacious = array(
		'id'			                            => 4,
		'kb_name'			                        => 'Spacious',
		'theme_desc'			                    => 'Big icons for easy navigation',
		'kb_articles_common_path'			        => 'knowledge-base-2',
		'templates_for_kb_padding_left'			    => '4',
		'templates_for_kb_padding_right'			=> '4',
		'templates_for_kb_margin_left'			    => '4',
		'templates_for_kb_margin_right'			    => '4',
		'templates_for_kb_category_archive_page_style' => 'eckb-category-archive-style-2',
		'breadcrumb_text_color'			            => '#1e73be',
		'back_navigation_text_color'			    => '#1e73be',
		'width'			                            => 'epkb-boxed',
		'search_box_input_width'			        => '80',
		'section_head_alignment'			        => 'center',
		'section_head_category_icon_location'		=> 'top',
		'section_head_category_icon_size'			=> '30',
		'section_divider_thickness'			        => '1',
		'section_border_width'			            => '1',
		'section_body_height'                       => 150,
		'search_title_font_color'			        => '#000000',
		'search_background_color'			        => '#ffffff',
		'search_text_input_border_color'			=> '#CCCCCC',
		'search_btn_background_color'			    => '#1168bf',
		'search_btn_border_color'			        => '#F1F1F1',
		'article_font_color'			            => '#000000',
		'article_icon_color'			            => '#1168bf',
		'section_border_color'			            => '#d1d1d1',
		'section_head_font_color'			        => '#000000',
		'section_divider_color'			            => '#CDCDCD',
		'section_category_font_color'			    => '#000000',
		'section_category_icon_color'			    => '#1e73be',
		'section_head_category_icon_color'			=> '#1e73be'
	);

	public static $theme_organized = array(
		'id'			                            => 2,
		'kb_name'			                        => 'Organized',
		'theme_desc'			                    => 'Divide into tabs and categories',
		'kb_articles_common_path'			        => 'knowledge-base-3',
		'kb_main_page_layout'			            => 'Tabs',
		'templates_for_kb_category_archive_page_style'			 => 'eckb-category-archive-style-3',
		'breadcrumb_text_color'			            => '#8c1515',
		'back_navigation_text_color'			    => '#8c1515',
		'width'			                            => 'epkb-boxed',
		'section_font_size'			                => 'section_small_font',
		'expand_articles_icon'			            => 'ep_font_icon_plus_box',
		'search_box_input_width'			        => '40',
		'section_head_alignment'			        => 'center',
		'section_head_category_icon_location'		=> 'top',
		'section_head_category_icon'			    => 'ep_font_icon_pencil',
		'section_divider'			                => 'off',
		'section_divider_thickness'			        => '1',
		'section_box_shadow'			            => 'section_light_shadow',
		'section_body_height'                       => 150,
		'section_head_padding_top'			        => '10',
		'section_head_padding_bottom'			    => '10',
		'section_border_width'			            => '1',
		'section_body_padding_left'			        => '22',
		'section_body_padding_right'			    => '4',
		'article_list_spacing'			            => '4',
		'search_title'			                    => 'Have a Question?',
		'search_background_color'			        => '#8c1515',
		'search_text_input_border_color'			=> '#000000',
		'search_btn_background_color'			    => '#878787',
		'search_btn_border_color'			        => '#000000',
		'article_font_color'			            => '#8c1515',
		'article_icon_color'			            => '#000000',
		'section_border_color'			            => '#bababa',
		'section_head_font_color'			        => '#000000',
		'section_head_background_color'			    => '#eeeeee',
		'section_divider_color'			            => '#CDCDCD',
		'section_category_font_color'			    => '#868686',
		'section_category_icon_color'			    => '#8c1515',
		'section_head_category_icon_color'			=> '#8c1515',
		'tab_down_pointer'			                => 'on',
		'tab_nav_active_font_color'			        => '#8c1515',
		'tab_nav_active_background_color'			=> '#F1F1F1',
		'tab_nav_font_color'			            => '#686868',
		'tab_nav_border_color'			            => '#000000'
	);

	public static $theme_organized_2 = array(
		'id'			                        => 3,
		'kb_name'			                    => 'Organized 2',
		'theme_desc'			                => 'Tabs for each section',
		'kb_articles_common_path'			    => 'knowledge-base-4',
		//'section_desc_text_on'			        => 'on',
		'kb_main_page_layout'			        => 'Tabs',
		'templates_for_kb_category_archive_page_style'			 => 'eckb-category-archive-style-4',
		'breadcrumb_text_color'			        => '#00b4b3',
		'back_navigation_text_color'			=> '#00b4b3',
		'nof_articles_displayed'			    => '10',
		'section_box_height_mode'               => 'section_no_height',
	//	'section_body_height'                   => '10',
		'expand_articles_icon'			        => 'ep_font_icon_right_arrow',
		'search_layout'			                => 'epkb-search-form-3',
		'search_input_border_width'			    => '5',
		'search_box_padding_top'			    => '50',
		'search_box_padding_bottom'			    => '50',
		'section_head_alignment'			    => 'center',
		'section_head_category_icon_location'	=> 'no_icons',
		'section_divider_thickness'			    => '1',
		'section_border_width'			        => '1',
		'section_body_padding_left'			    => '22',
		'section_body_padding_right'			=> '4',
		'article_list_spacing'			        => '4',
		'search_background_color'			    => '#00b4b3',
		'search_text_input_border_color'		=> '#00c6c6',
		'search_btn_background_color'			=> '#686868',
		'search_btn_border_color'			    => '#F1F1F1',
		'article_font_color'			        => '#000000',
		'article_icon_color'			        => '#00b4b3',
		'section_head_font_color'			    => '#ffffff',
		'section_head_background_color'			=> '#00b4b3',
		'section_divider_color'			        => '#CDCDCD',
		'section_category_font_color'			=> '#000000',
		'section_category_icon_color'			=> '#00b4b3',
		'section_head_category_icon_color'		=> '#868686',
		'search_title'			                => 'Help Center',
		'show_all_articles_msg'			        => 'Show all articles',
		'tab_nav_active_font_color'			    => '#ffffff',
		'tab_nav_active_background_color'		=> '#00b4b3',
		'tab_nav_font_color'			        => '#686868'
	);

	public static $theme_informative = array(
		'id'			                        => 5,
		'kb_name'			                    => 'Informative',
		'theme_desc'			                => 'Categories with description',
		'kb_articles_common_path'			    => 'knowledge-base-5',
		'kb_main_page_layout'			        => 'Basic',
		'templates_for_kb_padding_left'         => '4',
		'templates_for_kb_padding_right'        => '4',
		'templates_for_kb_margin_left'          => '4',
		'templates_for_kb_margin_right'         => '4',
		'nof_articles_displayed'                => '8',
		'search_box_input_width'                => '40',
		'section_head_alignment'			    => 'center',
		'section_head_category_icon_location'	=> 'top',
		'section_head_category_icon_size'	    => 50,
		'section_divider_thickness'			    => '0',
		'section_box_shadow'                    =>  'section_light_shadow',
		'section_border_width'                  => '0',
		'section_body_padding_top'              => '5',
		'section_body_height'                   => 150,
		'search_title_font_color'               => '#ffffff',
		'search_background_color'			    => '#904e95',
		'search_text_input_border_color'        => '#CCCCCC',
		'search_btn_background_color'			=> '#686868',
		'search_btn_border_color'			    => '#F1F1F1',
		'article_font_color'			        => '#606060',
		'article_icon_color'			        => '#904e95',
		'section_border_color'                  => '#DBDBDB',
		'section_head_font_color'               => '#827a74',
		'section_divider_color'                 => '#DADADA',
		'section_category_font_color'			=> '#868686',
		'section_category_icon_color'			=> '#868686',
		'section_desc_text_on'			        => 'on',
		'section_body_padding_left'             => 30,
		'category_box_heading_group'			=> '#904e95',
		'section_head_category_icon_color'		=> '#904e95',
		'search_title'			                => 'How Can We Help?',
		'search_title_font_size'			    => 40
	);

	public static $theme_modern = array(
		'id'			                        => 6,
		'kb_name'			                    => 'Modern',
		'theme_desc'			                => 'Modern simple look',
		'kb_articles_common_path'			    => 'knowledge-base-6',
		'kb_main_page_layout'			        => 'Basic',
		'templates_for_kb_padding_left'         => '4',
		'templates_for_kb_padding_right'        => '4',
		'templates_for_kb_margin_left'          => '4',
		'templates_for_kb_margin_right'         => '4',
		'nof_articles_displayed'                => '8',
		//Search
		'search_box_input_width'                => '40',
		'search_title'			                => 'Have a Question?',
		'search_title_font_size'			    => 40,
		'search_title_font_color'               => '#ffffff',
		'search_background_color'			    => '#FFFFFF',
		'search_text_input_border_color'        => '#40474f',
		'search_btn_background_color'			=> '#40474f',
		'search_btn_border_color'			    => '#40474f',
		'search_input_border_width'             => 3,

		//Section
		'section_head_alignment'			    => 'center',
		'section_head_category_icon_location'	=> 'no_icons',
		'section_head_category_icon_size'	    => 50,
		'section_divider_thickness'			    => '1',
		'section_box_shadow'                    =>  'section_light_shadow',
		'section_border_width'                  => '0',
		'section_body_padding_top'              => '5',
		'section_body_height'                   => 150,
		'section_border_color'                  => '#DBDBDB',
		'section_head_font_color'               => '#827a74',
		'section_divider_color'                 => '#DADADA',
		'section_category_font_color'			=> '#868686',
		'section_category_icon_color'			=> '#868686',
		'section_body_padding_left'             => 30,
		'category_box_heading_group'			=> '#904e95',
		'section_head_category_icon_color'		=> '#904e95',
		//Articles
		'article_font_color'			        => '#606060',
		'article_icon_color'			        => '#81d742',
	);

	public static $theme_bright = array(
		'id'			                        => 7,
		'kb_name'			                    => 'Bright',
		'theme_desc'			                => 'Focus on colors',
		'kb_articles_common_path'			    => 'knowledge-base-7',
		'kb_main_page_layout'			        => 'Basic',
		'templates_for_kb_padding_left'         => '4',
		'templates_for_kb_padding_right'        => '4',
		'templates_for_kb_margin_left'          => '4',
		'templates_for_kb_margin_right'         => '4',
		'nof_articles_displayed'                => '8',
		//Search
		'search_box_input_width'                => '40',
		'search_title'			                => 'What are you looking for?',
		'search_title_font_size'			    => 40,
		'search_title_font_color'               => '#ffffff',
		'search_background_color'			    => '#FFFFFF',
		'search_text_input_border_color'        => '#f4c60c',
		'search_btn_background_color'			=> '#f4c60c',
		'search_btn_border_color'			    => '#f4c60c',
		'search_input_border_width'             => 3,

		//Section
		'section_head_background_color'         =>  '#fcfcfc',
		'section_head_alignment'			    => 'left',
		'section_head_category_icon_location'	=> 'left',
		'section_head_category_icon_size'	    => 25,
		'section_head_category_icon_color'		=> '#f4c60c',
		'section_head_font_color'               => '#0b6ea0',

		'section_divider_thickness'			    => '2',
		'section_box_shadow'                    =>  'no_shadow',
		'section_border_width'                  => '0',
		'section_body_padding_top'              => '5',
		'section_body_height'                   => 150,
		'section_border_color'                  => '#DBDBDB',
		'section_divider_color'                 => '#edf2f6',
		'section_category_font_color'			=> '#868686',
		'section_category_icon_color'			=> '#dddddd',
		'section_body_padding_left'             => 10,
		'category_box_heading_group'			=> '#904e95',

		//Articles
		'article_font_color'			        => '#0bcad9',
		'article_icon_color'			        => '#1e1e1e',
		'expand_articles_icon'			        => 'ep_font_icon_right_arrow',
	);

	public static $theme_formal = array(
		'id'			                        => 8,
		'kb_name'			                    => 'Formal',
		'theme_desc'			                => 'Left alligned',
		'kb_articles_common_path'			    => 'knowledge-base-8',
		'kb_main_page_layout'			        => 'Basic',
		'templates_for_kb_padding_left'         => '4',
		'templates_for_kb_padding_right'        => '4',
		'templates_for_kb_margin_left'          => '4',
		'templates_for_kb_margin_right'         => '4',
		'nof_articles_displayed'                => '8',
		//Search
		'search_box_input_width'                => '40',
		'search_title'			                => 'Welcome to our Knowledge Base',
		'search_title_font_size'			    => 40,
		'search_title_font_color'               => '#000000',
		'search_background_color'			    => '#edf2f6',
		'search_text_input_border_color'        => '#d1d1d1',
		'search_btn_background_color'			=> '#666666',
		'search_btn_border_color'			    => '#666666',
		'search_input_border_width'             => 1,
		'search_box_padding_top'			    => '50',
		'search_box_padding_bottom'			    => '50',

		//Section
		'section_head_alignment'			    => 'left',
		'section_head_category_icon_location'	=> 'left',
		'section_head_category_icon_size'	    => 25,
		'section_head_category_icon_color'		=> '#e3474b',
		'section_head_font_color'               => '#e3474b',

		'section_divider_thickness'			    => '2',
		'section_box_shadow'                    =>  'no_shadow',
		'section_border_width'                  => '0',
		'section_body_padding_top'              => '5',
		'section_body_height'                   => 150,
		'section_border_color'                  => '#DBDBDB',
		'section_divider_color'                 => '#edf2f6',
		'section_category_font_color'			=> '#868686',
		'section_category_icon_color'			=> '#e3474b',
		'section_body_padding_left'             => 10,
		'category_box_heading_group'			=> '#904e95',

		//Articles
		'article_font_color'			        => '#616161',
		'article_icon_color'			        => '#000000',
		'expand_articles_icon'			        => 'ep_font_icon_right_arrow',
	);

	public static $theme_disctinct = array(
		'id'			                        => 9,
		'kb_name'			                    => 'Distinct',
		'theme_desc'			                => 'Categories above articles',
		'kb_articles_common_path'			    => 'knowledge-base-9',
		'kb_main_page_layout'			        => 'Basic',
		'templates_for_kb_padding_left'         => '4',
		'templates_for_kb_padding_right'        => '4',
		'templates_for_kb_margin_left'          => '4',
		'templates_for_kb_margin_right'         => '4',
		'nof_articles_displayed'                => '8',
		'show_articles_before_categories'       => 'off',
		//Search
		'search_box_input_width'                => '40',
		'search_title'			                => 'Self Help Documentation',
		'search_title_font_size'			    => 40,
		'search_title_font_color'               => '#528ffe',
		'search_background_color'			    => '#f4f8ff',
		'search_text_input_border_color'        => '#bf25ff',
		'search_btn_background_color'			=> '#bf25ff',
		'search_btn_border_color'			    => '#bf25ff',
		'search_input_border_width'             => 1,
		'search_box_padding_top'                => 30,
		'search_box_padding_bottom'             => 30,

		//Section
		'section_head_alignment'			    => 'center',
		'section_head_category_icon_location'	=> 'left',
		'section_head_category_icon_size'	    => 25,
		'section_head_category_icon_color'		=> '#bf25ff',
		'section_head_font_color'               => '#528ffe',

		'section_divider_thickness'			    => '2',
		'section_box_shadow'                    =>  'no_shadow',
		'section_border_width'                  => '0',
		'section_body_padding_top'              => '5',
		'section_body_height'                   => 150,
		'section_box_height_mode'               => 'section_no_height',
		'section_border_color'                  => '#528ffe',
		'section_divider_color'                 => '#528ffe',
		'section_category_font_color'			=> '#868686',
		'section_category_icon_color'			=> '#528ffe',
		'section_body_padding_left'             => 10,
		'category_box_heading_group'			=> '#904e95',

		//Articles
		'article_font_color'			        => '#566e8b',
		'article_icon_color'			        => '#566e8b',
		'expand_articles_icon'			        => 'ep_font_icon_plus_box',
	);

	public static $theme_faqs = array(
		'id'			                        => 10,
		'kb_name'			                    => 'FAQs',
		'theme_desc'			                => 'List of topics and articles',
		'kb_articles_common_path'			    => 'knowledge-base-10',
		'kb_main_page_layout'			        => 'Basic',
		'templates_for_kb_padding_left'         => '4',
		'templates_for_kb_padding_right'        => '4',
		'templates_for_kb_margin_left'          => '4',
		'templates_for_kb_margin_right'         => '4',
		'nof_articles_displayed'                => '8',
		'nof_columns'                           => 'two-col',

		//Search
		'search_box_input_width'                => '40',
		'search_title'			                => 'Support Center',
		'search_title_font_size'			    => 40,
		'search_title_font_color'               => '#ffffff',
		'search_background_color'			    => '#37de89',
		'search_text_input_border_color'        => '#37de89',
		'search_btn_background_color'			=> '#666666',
		'search_btn_border_color'			    => '#666666',
		'search_input_border_width'             => 1,
		'search_box_padding_top'                => 30,
		'search_box_padding_bottom'             => 30,
		'search_layout'                         => 'epkb-search-form-0',

		//Section
		'section_head_alignment'			    => 'left',
		'section_head_category_icon_location'	=> 'left',
		'section_head_category_icon_size'	    => 25,
		'section_head_category_icon_color'		=> '#bf25ff',
		'section_head_font_color'               => '#528ffe',

		'section_divider_thickness'			    => '2',
		'section_box_shadow'                    =>  'no_shadow',
		'section_border_width'                  => '0',
		'section_body_padding_top'              => '5',
		'section_body_height'                   => 90,
		'section_border_color'                  => '#528ffe',
		'section_divider_color'                 => '#528ffe',
		'section_category_font_color'			=> '#868686',
		'section_category_icon_color'			=> '#528ffe',
		'section_body_padding_left'             => 10,
		'section_body_padding_bottom'           => 0,
		'category_box_heading_group'			=> '#904e95',

		//Articles
		'article_font_color'			        => '#566e8b',
		'article_icon_color'			        => '#566e8b',
		'expand_articles_icon'			        => 'ep_font_icon_right_arrow',
	);

}