<?php  if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Display KB configuration Wizard
 *
 * @copyright   Copyright (C) 2018, Echo Plugins
 * @license http://opensource.org/licenses/gpl-2.0.php GNU Public License
 */
class EPKB_KB_Wizard {

	var $kb_config = array();
	/** @var  EPKB_KB_Config_Elements */
	var $form;
	var $feature_specs = array();
	/** @var EPKB_HTML_Elements */
	var $html;
	var $templates;
	var $kb_id;
	var $is_existing_kb;
	var $is_blank_kb;

	function __construct() {
		$_POST['epkb-wizard-demo-data'] = true;
		new EPKB_KB_Wizard_Colors();
		add_filter('admin_body_class', array($this, 'admin_wizard_body_class') );
	}

	/**
	 * Show Wizard page
	 * @param $kb_config
	 */
	public function display_kb_wizard( $kb_config ) {

		$this->kb_config              = $kb_config;
		$this->kb_id                  = $this->kb_config['id'];
		$this->feature_specs          = EPKB_KB_Config_Specs::get_fields_specification( $this->kb_config['id'] );
		$this->form                   = new EPKB_KB_Config_Elements();
		$this->html                   = NEW EPKB_HTML_Elements();

		// core handles only default KB
		if ( $this->kb_id != EPKB_KB_Config_DB::DEFAULT_KB_ID && ! defined( 'E' . 'MKB_PLUGIN_NAME' ) ) {
			echo '<div class="epkb-wizard-error-note">Ensure that Multiple KB add-on is active and refresh this page. Please contact us, click <a href="https://www.echoknowledgebase.com/technical-support/" target="_blank" rel="noopener noreferrer">here</a> for support.</div>';
			return;
		}

		// ensure KB config is there
		$kb_config = epkb_get_instance()->kb_config_obj->get_kb_config( $this->kb_id );
		if ( is_wp_error( $kb_config ) || empty($kb_config) || ! is_array($kb_config) || count($kb_config) < 100 ) {
			echo '<div class="epkb-wizard-error-note">Error occurred (x1). Please contact us, click <a href="https://www.echoknowledgebase.com/technical-support/" target="_blank" rel="noopener noreferrer">here</a> for support.</div>';
			return;
		}

		$this->is_blank_kb = EPKB_Utilities::is_blank_KB( $this->kb_id );
		if ( is_wp_error($this->is_blank_kb) ) {
			echo '<div class="epkb-wizard-error-note">Error occurred (x2). Please contact us, click <a href="https://www.echoknowledgebase.com/technical-support/" target="_blank" rel="noopener noreferrer">here</a> for support.</div>';
			return;
		}

		$this->is_existing_kb = EPKB_Utilities::is_existing_KB( $this->kb_id );
		if ( is_wp_error($this->is_existing_kb) ) {
			echo '<div class="epkb-wizard-error-note">Error occurred (x3). Please contact us, click <a href="https://www.echoknowledgebase.com/technical-support/" target="_blank" rel="noopener noreferrer">here</a> for support.</div>';
			return;
		}

		$this->templates = EPKB_KB_Wizard_Themes::get_all_themes();
		if ( empty($this->templates[0]) ) {
			echo '<div class="epkb-wizard-error-note">Error occurred (x4). Please contact us, click <a href="https://www.echoknowledgebase.com/technical-support/" target="_blank" rel="noopener noreferrer">here</a> for support.</div>';
			return;
		}		?>

		<div class="" id="epkb-config-wizard-content">
			<div class="epkb-config-wizard-inner">

				<!------- Wizard Header ------------>
				<div class="epkb-wizard-header">
					<div class="epkb-wizard-header__info">
						<h1 class="epkb-wizard-header__info__title">
							Wizard
						</h1>
						<span class="epkb-wizard-header__info__current-kb">							<?php
							$kb_name = $this->kb_config['kb_name'];
							echo 'For <span id="epkb_current_kb_name" class="epkb-wizard-header__info__current-kb__name">'.esc_html( $kb_name ).'</span>';					?>
						</span>

						<div class="epkb-wizard-button epkb-wizard-header__info__desc-toggle">
							<span class="epkb-wizard-desc-toggle__text">Step Info</span>
							<span class="epkb-wizard-desc-toggle__icon epkbfa epkbfa-info-circle"></span>
						</div>
					</div>

					<div class="epkb-wizard-button-link epkb-wizard-header__exit-wizard">
						<a href="<?php echo esc_url( admin_url('edit.php?post_type=' . EPKB_KB_Handler::get_post_type( $this->kb_config['id'] )) ); ?>&page=epkb-kb-configuration">
							Exit Wizard
						</a>
					</div>

					<div class="epkb-wizard-header__desc-container">
						<p id="epkb-wizard-desc-step-1" class="epkb-wizard-header__desc__step epkb-wizard-desc-active">Start setting up your Knowledge Base (KB for short) with configuration of the title and URL.</p>
						<p id="epkb-wizard-desc-step-2" class="epkb-wizard-header__desc__step">Choose a template that best matches the design you want. You can modify its colors in later steps.</p>
						<p id="epkb-wizard-desc-step-3" class="epkb-wizard-header__desc__step">Choose from preset colors on the right or modify them individually on the left.</p>
						<p id="epkb-wizard-desc-step-4" class="epkb-wizard-header__desc__step">Choose the colors of the elements within the article page. If a color is not available here, that means it is controlled by your theme.</p>
						<p id="epkb-wizard-desc-step-5" class="epkb-wizard-header__desc__step">After you hit the Apply button we will create your knowledge base according to your selection.</p>
					</div>
				</div>

				<!------- Wizard Status Bar ------->
				<div class="epkb-wizard-status-bar">
					<ul>
						<li id="epkb-wsb-step-1" class="epkb-wsb-step epkb-wsb-step--active">Title & URL</li>
						<li id="epkb-wsb-step-2" class="epkb-wsb-step">Theme</li>
						<li id="epkb-wsb-step-3" class="epkb-wsb-step">Main Page Colors</li>
						<li id="epkb-wsb-step-4" class="epkb-wsb-step">Article Page Colors</li>
						<li id="epkb-wsb-step-5" class="epkb-wsb-step">Finish</li>
					</ul>
				</div>

				<!------- Wizard Content ---------->
				<div class="epkb-wizard-content">
					<?php $this->wizard_step_title_url(); ?>
					<?php $this->wizard_step_theme(); ?>
					<?php $this->wizard_step_main_page_colors(); ?>
					<?php $this->wizard_step_article_page_colors(); ?>
					<?php $this->wizard_step_finish(); ?>
				</div>

				<!------- Wizard Footer ---------->
				<div class="epkb-wizard-footer">
					<?php $this->wizard_buttons(); ?>
				</div>
				
				<div id='epkb-ajax-in-progress' style="display:none;">
					<?php esc_html__( 'Saving configuration', 'echo-knowledge-base' ); ?> <img class="epkb-ajax waiting" style="height: 30px;" src="<?php echo Echo_Knowledge_Base::$plugin_url . 'img/loading_spinner.gif'; ?>">
				</div>
				<input type="hidden" id="epkb_wizard_kb_id" name="epkb_wizard_kb_id" value="<?php echo $this->kb_id; ?>"/>

				<div class="eckb-bottom-notice-message"></div>
			</div>
		</div> <?php
	}

	// Wizard: Step 1 - Title & URL
	private function wizard_step_title_url() {

		// TODO fix
		if ( $this->is_wizard_disabled() ) {   ?>
			<div id="epkb-wsb-step-1-panel" class="epkb-wc-step-panel epkb-wizard-step-1  epkb-wc-step-panel--active">
				<div>This wizard is currently only available for new KB installs. Updated Wizard will be released soon.</div>
			</div>      <?php
			return;
		}

		$url_change_warning = '';
		if ( ! $this->is_blank_kb ) {
			// TODO $url_change_warning = 'If you change Knowledge Base URL you might need to update links to KB articles.';
			$url_change_warning = '<div class="epkb-wizard-warning-note">NOTE: Currently the Wizard does not support updates to the KB slug. To update the slug go to KB Configuration -> Article Page -> Tuning -> Article Common Path.</div>';
		}       ?>

		<div id="epkb-wsb-step-1-panel" class="epkb-wc-step-panel epkb-wizard-step-1  epkb-wc-step-panel--active">  <?php

			if ( $this->is_blank_kb ) {      ?>
				<h3 class="epkb-wsb-welcome-msg">Hi and welcome to the Knowledge Base Wizard. <br/>Let's start with naming your KB.</h3>		<?php
			}

			$this->html->text(
				array(
					'label'             => 'Knowledge Base Title',
					'placeholder'       => 'Knowledge Base',
					'main_tag'          => 'div',
					'input_group_class' => 'epkb-wizard-row-form-input epkb-wizard-name',
					'value'             => $this->kb_config['kb_name']
				)
			);      ?>
			<div class="epkb-wizard-row-form-input">
				<div class="epkb-wizard-col2">
					<p class="epkb-wizard-input-desc">Name and page title of your knowledge base<br/>Examples: Knowledge Base, Help, Support
					</p>
				</div>
			</div>			<?php

			// only initial KB slug can be set here
			if ( $this->is_blank_kb ) {

				$this->html->text(
					array(
						'label'             => 'Knowledge Base URL',
						'placeholder'       => 'knowledge-base',
						'main_tag'          => 'div',
						'readonly'          => $this->is_existing_kb,
						'input_group_class' => 'epkb-wizard-row-form-input epkb-wizard-slug',
						'value'             => _x( 'knowledge-base', 'initial SLUG for KB', 'echo-knowledge-base' )
					)
				);      ?>
				<div class="epkb-wizard-row-form-input">
					<div class="epkb-wizard-col2">
						<p class="epkb-wizard-input-desc">The main part of your knowledge base URL.<br/>Example of KB URL: &nbsp;&nbsp;www.your-domain.com/knowledge-base/
							<?php echo $url_change_warning; ?>
						</p>
					</div>

				</div>  <?php
			}    ?>

		</div>	<?php
	}

	// Wizard: Step 2 - Theme
	private function wizard_step_theme() {		?>

		<div id="epkb-wsb-step-2-panel" class="epkb-wc-step-panel epkb-wizard-step-2">
			<div class="epkb-wizard-theme-preview">

				<!-- THEME BUTTONS -->
				<div class="epkb-wizard-theme-tab-container">
					<input type="hidden" id="_wpnonce_wizard_templates" name="_wpnonce_wizard_templates" value="<?php echo wp_create_nonce( "_wpnonce_wizard_templates" ); ?>"/>
					<ul>						<?php
						$first_theme = true;
						$first_theme_id = $this->is_blank_kb ? 1 : 0;
						foreach ( $this->templates as $template ) {								?>
							<li id="epkb-wt-theme-<?php echo $first_theme ? $first_theme_id : $template['id']; ?>" class="epkb-wt-tab<?php echo $first_theme ? ' epkb-wt--active epkb-wt--current' : ''; ?>" data-template_id="<?php echo $first_theme ? $first_theme_id : $template['id']; ?>" >
								<div class="epkb-wt-tab__name"><?php echo $template['kb_name']; ?></div>
								<div class="epkb-wt-tab__desc"><?php echo $first_theme ? 'Your current KB configuration' : $template['theme_desc']; ?></div>
							</li>   <?php
							$first_theme = false;
						}						?>
					</ul>
				</div>

				<!-- THEME PREVIEW -->
				<div class="epkb-wizard-theme-panel-container">					<?php
					$first_theme = true;
					$first_theme_id = $this->is_blank_kb ? 1 : 0;
					foreach ( $this->templates as $template ) {   ?>
						<div id="epkb-wt-theme-<?php echo $first_theme ? $first_theme_id : $template['id']; ?>-panel" class="epkb-wt-panel<?php echo $first_theme ? ' epkb-wt-panel--active' : ''; ?>">	<?php
							$handler = new EPKB_KB_Config_Page( EPKB_KB_Wizard_Themes::get_theme( $first_theme ? $first_theme_id : $template['id'] ) );
							$handler->display_kb_main_page_layout_preview();
							echo '<input type="hidden" class="theme-values" value="' . EPKB_KB_Wizard_Themes::get_theme_data( $first_theme ? $first_theme_id : $template['id'] ) . '">'; ?>
						</div>	<?php
						$first_theme = false;
					}					?>
				</div>

			</div>
		</div>	<?php
	}

	// Wizard: Step 3 - Main Page Colors
	private function wizard_step_main_page_colors() {		?>

		<div id="epkb-wsb-step-3-panel" class="epkb-wc-step-panel epkb-wizard-step-3">
			<div class="epkb-wizard-color-preview">
				<div class="epkb-wizard-color-preset-container">
					<ul>
						<li id="epkb-wc-preset-0" class="epkb-wcp-tab epkb-preset-button" data-colors="">Current Theme</li>
						<li id="epkb-wc-preset-1" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 1 ); ?>">Yellow</li>
						<li id="epkb-wc-preset-3" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 3 ); ?>">Light Blue</li>
						<li id="epkb-wc-preset-4" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 4 ); ?>">Medium Blue</li>
						<li id="epkb-wc-preset-4" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 5 ); ?>">Dark Blue</li>
						<li id="epkb-wc-preset-3" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 6 ); ?>">Light Green</li>
						<li id="epkb-wc-preset-4" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 7 ); ?>">Medium Green</li>
						<li id="epkb-wc-preset-4" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 8 ); ?>">Dark Green</li>
						<li id="epkb-wc-preset-3" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 9 ); ?>">Light Red</li>
						<li id="epkb-wc-preset-4" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 10 ); ?>">Medium Red</li>
						<li id="epkb-wc-preset-4" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 11 ); ?>">Dark Red</li>
						<li id="epkb-wc-preset-3" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 12 ); ?>">Light Gray</li>
						<li id="epkb-wc-preset-4" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 13 ); ?>">Medium Gray</li>
						<li id="epkb-wc-preset-4" class="epkb-wcp-tab epkb-preset-button" data-colors="<?php echo EPKB_KB_Wizard_Color_Presets::get_template_data( 14 ); ?>">Dark Gray</li>
					</ul>
				</div>
				<div id="eckb-wizard-main-page-preview" class="epkb-wizard-theme-preview-container">
					
				</div>
				<div class="epkb-wizard-color-selection-container epkb-accordion">
					<?php $this->wizard_section( 'epkb-wizard-main-page-color-selection-container', array( 'id' => $this->kb_config, 'config' => $this->kb_config ) ); ?>
				</div>
			</div>
		</div>	<?php
	}

	// Wizard: Step 4 - Article Page Colors
	private function wizard_step_article_page_colors() {        ?>

		<div id="epkb-wsb-step-4-panel" class="epkb-wc-step-panel epkb-wizard-step-4">
			<div class="epkb-wizard-color-preview">

				<div id="eckb-wizard-article-page-preview" class="epkb-wizard-theme-preview-container">					<?php
					$handler = new EPKB_KB_Config_Page( EPKB_KB_Wizard_Themes::get_theme( 0 ) );
					$handler->display_article_page_layout_preview( true ); ?>
				</div>
				<div class="epkb-wizard-color-selection-container epkb-accordion">
					<?php $this->wizard_section( 'epkb-wizard-article-page-color-selection-container', array( 'id' => $this->kb_config, 'config' => $this->kb_config ) ); ?>
				</div>
			</div>
		</div>	<?php
	}

	// Wizard: Step 5 - Finish
	private function wizard_step_finish() {

		$page_title = "Final Step: " . ( $this->is_blank_kb ? "Generate New Knowledge Base" : "Update Your Knowledge Base" );
		$page_description = $this->is_blank_kb ? "Click Apply to generate your custom styled Knowledge Base." : "Click Apply to update your Knowledge Base configuration based on selection from previous Wizard screens.";		?>

		<div id="epkb-wsb-step-5-panel" class="epkb-wc-step-panel epkb-wizard-step-5" >

				<h2><?php echo $page_title; ?></h2>
				<p><?php echo $page_description; ?></p>

		</div>	<?php

		// display link to KB Main Page if any
		$link_output = EPKB_KB_Handler::get_first_kb_main_page_url( $this->kb_config );     ?>

		<div id="epkb-wsb-step-6-panel" class="epkb-wc-step-panel epkb-wizard-step-5" style="display: none">
			<div class="epkb-wizard-row-1">
				<p>See your KB on the front-end:</p>
				<a id="epkb-kb-main-page-link" href="<?php echo empty($link_output) ? '' : $link_output; ?>" target="_blank" class="epkb-wizard-button">
					<span class="epkb-wizard-btn-text">View My Knowledge base</span>
					<span class="epkb-wizard-btn-icon dashicons-before dashicons-welcome-learn-more"></span>
				</a>
			</div>

			<div class="epkb-wizard-row-1">
				<p>Create Categories from the Categories menu.</p>
				<a href="<?php echo admin_url('edit-tags.php?taxonomy=' . EPKB_KB_Handler::get_category_taxonomy_name( $this->kb_id ) .'&post_type=' . EPKB_KB_Handler::get_post_type( $this->kb_id )); ?>" target="_blank" class="epkb-wizard-button">
					<span class="epkb-wizard-btn-text">Create Categories</span>
					<span class="epkb-wizard-btn-icon epkbfa epkbfa-book"></span></a>
			</div>

			<div class="epkb-wizard-row-1">
				<p>Create Articles from the Add New Article menu.</p>
				<a href="<?php echo esc_url( admin_url('edit.php?post_type=' . EPKB_KB_Handler::get_post_type( $this->kb_id )) ); ?>" target="_blank" class="epkb-wizard-button">
					<span class="epkb-wizard-btn-text">Create Articles</span>
					<span class="epkb-wizard-btn-icon epkbfa epkbfa-file-text-o "></span>
				</a>
			</div>

			<div class="epkb-wizard-row-1">
				<p>Documentation for Knowledge Base and add-ons.</p>
				<a href="https://www.echoknowledgebase.com/documentation/getting-started" target="_blank" class="epkb-wizard-button">
					<span class="epkb-wizard-btn-text">KB Documentation</span>
					<span class="epkb-wizard-btn-icon epkbfa epkbfa-book"></span></a>
			</div>

			<div class="epkb-wizard-row-1">
				<p>Submit a technical support question.</p>
				<a href="https://www.echoknowledgebase.com/contact-us/" target="_blank" class="epkb-wizard-button">
					<span class="epkb-wizard-btn-text">Support</span>
					<span class="epkb-wizard-btn-icon epkbfa epkbfa-book"></span></a>
			</div>

			<?php /*
			$this->html->text(
				array(
					'label'             => 'Sign up for the Newsletter',
					'placeholder'       => 'Email Address',
					'main_tag'          => 'div',
					'input_group_class' => 'epkb-wizard-row-form-input',
				)
			); ?>
			<div class="epkb-wizard-row-form-input">
				<div class="epkb-wizard-col2">
					<p class="epkb-wizard-input-desc">We're here for you - get tips, product updates, and news!</p>
				</div>
			</div>


		</div>	<?php */
	}

	//Wizard: Previous / Next Buttons / Apply Buttons
	public function wizard_buttons() {
		// TODO remove
		if (  $this->is_wizard_disabled() ) {
			return;
		}   ?>

		<div class="epkb-wizard-button-container epkb-wizard-button-container--first-step">
			<div class="epkb-wizard-button-container__inner">
				<button value="0" id="epkb-wizard-button-prev" class="epkb-wizard-button epkb-wizard-button-prev">
					<span class="epkb-wizard-button-prev__icon epkbfa epkbfa-caret-left"></span>
					<span class="epkb-wizard-button-prev__text">Previous</span>
				</button>
				<button value="2" id="epkb-wizard-button-next" class="epkb-wizard-button epkb-wizard-button-next">
					<span class="epkb-wizard-button-next__text">Next</span>
					<span class="epkb-wizard-button-next__icon epkbfa epkbfa-caret-right"></span>
				</button>
				<button value="apply" id="epkb-wizard-button-apply" class="epkb-wizard-button epkb-wizard-button-apply">Apply</button>

				<input type="hidden" id="_wpnonce_apply_wizard_changes" name="_wpnonce_apply_wizard_changes" value="<?php echo wp_create_nonce( "_wpnonce_apply_wizard_changes" ); ?>">
			</div>
			<div class="epkb-wizard-link epkb-wizard-button-container__support-wizard">
				<a href="https://www.echoknowledgebase.com/technical-support/" target="_blank">
					Support
					<span class="epkbfa epkbfa-external-link"></span>
				</a>
			</div>
		</div>	<?php
	}

    private function is_wizard_disabled() {
		if ( defined( 'WIZARD_DEBUG' ) && WIZARD_DEBUG ) return false;
		
    	$plugin_version_first = get_option( 'epkb_version_first' );
		return empty($plugin_version_first) || defined('EL'.'AY_PLUGIN_NAME') || defined('AS'.'EA_PLUGIN_NAME') || defined('WI'.'DG_PLUGIN_NAME');
    }

	/**
	 * Call all hooks for given Wizard section.
	 *
	 * @param $hook - both hook name and div id
	 * @param $args
	 */
	public function wizard_section( $hook, $args ) {
		do_action( $hook, $args );
	}

    public function admin_wizard_body_class( $classes ) {
        // Note: Add a leading space and a trailing space.
        $classes .= ' epkb-wizard-page ';
        return $classes;
    }

	public static function get_changed_config( $orig_settings, $new_settings ) {

		$diff = EPKB_Utilities::diff_two_dimentional_arrays( $new_settings, $orig_settings );
		$changed_config = '';
		foreach( $diff as $key => $value ) {
			if ( isset($orig_settings[$key]) ) {
				$changed_config .= $key . ': ORIG: ' . $orig_settings[ $key ] . ' NEW: ' . $value . "<br/>";
			}
		}

		return $changed_config;
	}
}
