jQuery(document).ready(function($) {

	let ekb_admin_page_wrap = $( '#ekb-admin-page-wrap' );
	let wizard = $( '#epkb-config-wizard-content' );

	// If the Wizard is not detected don't run scripts.
	if ( wizard.length <= 0 ) {
		return;
	}

	/**
	 * Highlight all completed steps in status bar.
	 */
	function wizard_status_bar_highlight_completed_steps( nextStep ){

		// Clear Completed Classes
		wizard.find( '.epkb-wizard-status-bar .epkb-wsb-step' ).removeClass( 'epkb-wsb-step--completed' );

		wizard.find( '.epkb-wizard-status-bar .epkb-wsb-step' ).each( function(){

			// Get each Step ID
			id = $( this ).attr( 'id' );

			// Get last character the number of each ID
			let lastChar = id[id.length -1];

			// If the ID is less than the current step then add completed class.
			if( lastChar < nextStep ){
				$( this ).addClass( 'epkb-wsb-step--completed' );
			}
		});
	}

	/**
	 * Change Next button to apply button on last step.
	 * Remove Class for all steps other than the first: epkb-wizard-button-container--first-step
	 */
	function wizard_change_buttons(){
		wizard.find( '.epkb-wizard-button-container' ).removeClass( 'epkb-wizard-button-container--final-step' );
		wizard.find( '.epkb-wizard-button-container' ).removeClass( 'epkb-wizard-button-container--first-step' );

		let id = wizard.find( '.epkb-wsb-step--active' ).attr( 'id' );

		// Get last character the number of each ID
		let lastChar = Number(id[id.length -1]);

		if( lastChar === 1 ){
			wizard.find( '.epkb-wizard-button-container' ).addClass( 'epkb-wizard-button-container--first-step' );
		}
		if( lastChar === 5 ){
			wizard.find( '.epkb-wizard-button-container' ).addClass( 'epkb-wizard-button-container--final-step' );
		}
	}

	/**
	 * Change the Top Description based on step.
	 */
	function wizard_show_step_description(){

		// Get the current active step ID
		let id = $( '.epkb-wsb-step--active' ).attr( 'id' );

		// Get last character the number of each ID
		let lastChar = Number(id[id.length -1]);

		// Clear all active classes
		$( '.epkb-wizard-header__desc__step' ).removeClass( 'epkb-wizard-desc-active' );

		// Set the Active class based on ID
		$( '#epkb-wizard-desc-step-'+lastChar ).addClass( 'epkb-wizard-desc-active' );

	}
	
	/**
	 * Special functions for the turning steps to move data between steps 
	 */
	function wizard_changed_step(from, to) {

		// update KB name at the top
		if ( from == 1 && to == 2 ) {
			$('#epkb_current_kb_name').text($('.epkb-wizard-name input').val());
		}

		// update preview from theme selection on Main Page colors
		if ( from == 2 && to == 3) {
			// move template to the next step when we press 'next'
			$('#eckb-wizard-main-page-preview').html($('body').find('.epkb-wt-panel--active').html());
			
			let data = JSON.parse($('#eckb-wizard-main-page-preview').find('.theme-values').val());
			
			// set colors on the right panel to theme's colors 
			epkb_try_set_colors_on_panel( 
				data,
				$('.epkb-wizard-colors-content')
			);
			
			// enable/disable tabs 
			if ( data.kb_main_page_layout !== 'undefined' && data.kb_main_page_layout == 'Tabs' ) {
				// show tabs section 
				$('.tabs-colors-content').show();
			} else {
				// hide tabs section 
				$('.tabs-colors-content').hide();
			}
			
			// add first preset as current
			$('#epkb-wc-preset-0').data('colors', JSON.parse($('#eckb-wizard-main-page-preview').find('.theme-values').val()));
			let currentThemeName = $('.epkb-wt-tab.epkb-wt--active .epkb-wt-tab__name').text();
			currentThemeName = $('.epkb-wt-tab.epkb-wt--active').data().template_id == 0 ? 'Current KB' : currentThemeName;
			$('#epkb-wc-preset-0').text(currentThemeName);
		}
	}

	/**
	 * Quickly scroll the user back to the top.
	 */
	function wizard_scroll_to_top(){
		$("html, body").animate({ scrollTop: 0 }, 0);
	}

	/**
	 * Toggle the Step information
	 *
	 */
	wizard.find( '.epkb-wizard-header__info__desc-toggle' ).on( 'click', function(){
		wizard.find( '.epkb-wizard-header__desc-container' ).slideToggle();
	});


	/**
	 * Button JS for next Step.
	 *
	 */
	wizard.find( '#epkb-wizard-button-next' ).on( 'click' , function(e){
		e.preventDefault();

		// Get the Step values
		let nextStep = Number( wizard.find( '#epkb-wizard-button-next' ).val() );
		let prevStep = Number( wizard.find( '#epkb-wizard-button-prev' ).val() );

		// Remove all Active Step classes in Step Status Bar.
		$( '.epkb-wsb-step' ).removeClass( 'epkb-wsb-step--active' );

		// Add Active class to next Step in Status Bar.
		$( '#epkb-wsb-step-'+nextStep ).addClass( 'epkb-wsb-step--active' );

		// Remove all active class from panels.
		$( '.epkb-wc-step-panel' ).removeClass( 'epkb-wc-step-panel--active' );

		// Add Active class to next panel in the steps.
		$( '#epkb-wsb-step-'+nextStep+'-panel' ).addClass( 'epkb-wc-step-panel--active' );

		// Update the Previous and Next Data values.
		$( '#epkb-wizard-button-prev' ).val( prevStep+1 );
		$( '#epkb-wizard-button-next' ).val( nextStep+1 );

		wizard_status_bar_highlight_completed_steps( nextStep );
		wizard_change_buttons();
		wizard_show_step_description();
		wizard_changed_step(nextStep-1, nextStep);
		wizard_scroll_to_top();
	});

	/**
	 * Button JS for prev Step.
	 *
	 */
	wizard.find( '#epkb-wizard-button-prev' ).on( 'click' , function(e){
		e.preventDefault();

		// Get the Step values
		let nextStep = Number( wizard.find( '#epkb-wizard-button-next' ).val() );
		let prevStep = Number( wizard.find( '#epkb-wizard-button-prev' ).val() );

		// Remove all Active Step classes in Step Status Bar.
		$( '.epkb-wsb-step' ).removeClass( 'epkb-wsb-step--active' );

		// Add Active class to next Step in Status Bar.
		$( '#epkb-wsb-step-'+prevStep ).addClass( 'epkb-wsb-step--active' );

		// Remove all active class from panels.
		$( '.epkb-wc-step-panel' ).removeClass( 'epkb-wc-step-panel--active' );

		// Add Active class to next panel in the steps.
		$( '#epkb-wsb-step-'+prevStep+'-panel' ).addClass( 'epkb-wc-step-panel--active' );

		// Update the Previous and Next Data values.
		$( '#epkb-wizard-button-prev' ).val( prevStep-1 );
		$( '#epkb-wizard-button-next' ).val( nextStep-1 );

		wizard_status_bar_highlight_completed_steps( prevStep );
		wizard_change_buttons();
		wizard_show_step_description();
		wizard_changed_step(prevStep+1,prevStep);
		wizard_scroll_to_top();
	});

	/**
	 * Theme Toggle JS
	 *
	 */
	wizard.find( '.epkb-wt-tab' ).on( 'click' , function(e){

		// Get Tab ID Value and Template ID
		let tab = $( this );
		let id = tab.attr( 'id' );
		let panel = $( '#'+id+'-panel' );

		// Remove all Active Tab classes
		$( '.epkb-wt-tab' ).removeClass( 'epkb-wt--active' );

		// Add Active class to click on theme.
		tab.addClass( 'epkb-wt--active' );

		// Remove all active class from panels.
		$( '.epkb-wt-panel' ).removeClass( ' epkb-wt-panel--active' );

		// Add Active class to panel with the same id
		panel.addClass( 'epkb-wt-panel--active' );
		
		// change styles for the tabs 
		let styles = JSON.parse(panel.find('.theme-values').val());
		console.log(styles);
		if (styles) {
		
			$('#epkb-advanced-style').html(`
				#epkb-content-container .epkb-nav-tabs .active:after {
					border-top-color: ${styles.tab_nav_active_background_color}!important
				}
				#epkb-content-container .epkb-nav-tabs .active {
					background-color: ${styles.tab_nav_active_background_color}!important
				}
				#epkb-content-container .epkb-nav-tabs .active .epkb-category-level-1,
				#epkb-content-container .epkb-nav-tabs .active p {
					color: ${styles.tab_nav_active_font_color}!important
				}
				#epkb-content-container .epkb-nav-tabs .active:before {
					border-top-color: ${styles.tab_nav_border_color}!important
				}		
			`);
			original_styles = $('#epkb-advanced-style').html();
		}
	});

	/** Change colors on the Main and Article page settings */
	
	let original_styles = $('#epkb-advanced-style').html();
	
	$('body').on('color_changed', 'input', function(){
		let that = $(this);
		
		setTimeout(function(){
		if ( that.data('target_selector') ) {
			let $target = $( that.data('target_selector') );
			
			if ($target.length) {
				let new_styles = {};
				new_styles[that.data('style_name')] = that.val();
				$target.css(new_styles);
			}
			console.log(that.data('target_selector'));
			if ( that.data('target_selector') == 'tab_nav_active_font_color' 
				|| that.data('target_selector') == 'tab_nav_active_background_color' 
				|| that.data('target_selector') == 'tab_nav_border_color' 
				|| that.data('target_selector') == 'article_toc_cursor_hover_bg_color'
				|| that.data('target_selector') == 'article_toc_active_bg_color'
				|| that.data('target_selector') == 'article_toc_active_text_color'
				|| that.data('target_selector') == 'article_toc_cursor_hover_text_color' ) { 
					let tab_nav_active_font_color = $('.epkb-wizard-step-3 input[name=tab_nav_active_font_color]').val();
					let tab_nav_active_background_color = $('.epkb-wizard-step-3 input[name=tab_nav_active_background_color]').val();
					let tab_nav_border_color = $('.epkb-wizard-step-3 input[name=tab_nav_border_color]').val();
					let article_toc_cursor_hover_bg_color = $('.epkb-wizard-step-4 input[name=article_toc_cursor_hover_bg_color]').val();
					let article_toc_cursor_hover_text_color = $('.epkb-wizard-step-4 input[name=article_toc_cursor_hover_text_color]').val();
					let article_toc_active_text_color = $('.epkb-wizard-step-4 input[name=article_toc_active_text_color]').val();
					let article_toc_active_bg_color = $('.epkb-wizard-step-4 input[name=article_toc_active_bg_color]').val();
					// special trigger for active tabs 
					$('#epkb-advanced-style').html( original_styles + `
						#epkb-wsb-step-3-panel #epkb-content-container .epkb-nav-tabs .active:after {
							border-top-color: ${tab_nav_active_background_color} !important;
						}
						#epkb-wsb-step-3-panel #epkb-content-container .epkb-nav-tabs .active {
							background-color: ${tab_nav_active_background_color} !important;
						}
						#epkb-wsb-step-3-panel #epkb-content-container .epkb-nav-tabs .active .epkb-category-level-1,
						#epkb-wsb-step-3-panel #epkb-content-container .epkb-nav-tabs .active p {
							color: ${tab_nav_active_font_color} !important;
						}
						#epkb-wsb-step-3-panel #epkb-content-container .epkb-nav-tabs .active:before {
							border-top-color: ${tab_nav_border_color} !important;
						}
						.epkb-wizard-step-4 .eckb-article-toc ul a.active {
							background: ${article_toc_active_bg_color} !important;
							color: ${article_toc_active_text_color} !important;
						}
						.epkb-wizard-step-4 .eckb-article-toc ul a:hover {
							background: ${article_toc_cursor_hover_bg_color} !important;
							color: ${article_toc_cursor_hover_text_color} !important;
						} 	`);
				}
		} }, 50);
	});

	/**
	 * Handle Apply Button
	 *
	 */
	wizard.find( '.epkb-wizard-button-apply' ).on( 'click' , function(e){

		// Get Tab ID Value and Template ID
		let kb_config = JSON.parse( $('#epkb-wsb-step-3-panel .theme-values').val() );
		
		// change template values to the values from inputs 
		$('#epkb-wsb-step-3-panel .epkb-wizard-colors-content input, #epkb-wsb-step-4-panel .epkb-wizard-colors-content input').each(function(){
			if (kb_config[$(this).attr('name')] !== 'undefined') {
				kb_config[$(this).attr('name')] = $(this).val();
			}
		});
		
		let postData = {
			action: 'epkb_apply_wizard_changes',
			_wpnonce_apply_wizard_changes: $('#_wpnonce_apply_wizard_changes').val(),
			kb_config: kb_config,
			epkb_wizard_kb_id: $('#epkb_wizard_kb_id').val(),
			kb_name: $('.epkb-wizard-name input').val(),
			kb_slug: $('.epkb-wizard-slug input').val()
		};
		let msg;
		// if (confirm('Really?')) {
			$.ajax({
				type: 'POST',
				dataType: 'json',
				data: postData,
				url: ajaxurl,
				beforeSend: function (xhr)
				{
					//noinspection JSUnresolvedVariable
					$('#epkb-ajax-in-progress').text(epkb_vars.save_config).dialog('open');
				}

			}).done(function (response)
			{
				response = ( response ? response : '' );
				if ( ! response.error && typeof response.message !== 'undefined' )
				{
					msg = response.message;
					
					$('#epkb-wsb-step-5-panel').removeClass('epkb-wc-step-panel--active');
					$('#epkb-kb-main-page-link').attr('href', response.kb_main_page_link);
					$('#epkb-wsb-step-6-panel').addClass('epkb-wc-step-panel--active').show();
					$('.epkb-wizard-button-container').hide();
					
				} else {
					//noinspection JSUnresolvedVariable
					msg = response.message ? response.message : epkb_admin_notification('', epkb_vars.reload_try_again, 'error');
				}

			}).fail(function (response, textStatus, error)
			{
				//noinspection JSUnresolvedVariable
				msg = ( error ? ' [' + error + ']' : epkb_vars.unknown_error );
				//noinspection JSUnresolvedVariable
				msg = epkb_admin_notification( epkb_vars.msg_try_again, msg, 'error' );
			}).always(function ()
			{
				$('#epkb-ajax-in-progress').dialog('close');

				if ( msg ) {
					$('.eckb-bottom-notice-message').replaceWith(msg);
					$("html, body").animate({scrollTop: 0}, "slow");
				}
			});
		//}
	});

	// SHOW INFO MESSAGES
	function epkb_admin_notification( $title, $message , $type ) {
		return '<div class="eckb-top-notice-message">' +
			'<div class="contents">' +
			'<span class="' + $type + '">' +
			($title ? '<h4>' + $title + '</h4>' : '' ) +
			($message ? $message : '') +
			'</span>' +
			'</div>' +
			'</div>';
	}
	
	/** 
	 * Set colors on the panel from JSON or object
	 * $data - json or object where { input_name : value }
	 * $panel_parent jQuery object with parent div of the color panel 
	*/
	function epkb_try_set_colors_on_panel( data, $panel_parent ) {
		
		if ( typeof $data == 'string') {
			data = JSON.parse( $data );
		}
		
		if (data.length == 0) {
			return;
		}
		
		// check colors 
		$panel_parent.find('input.wp-color-picker').each(function(){
			if ( typeof data[$(this).attr('name')] !== 'undefined' ) {
				$(this).val(data[$(this).attr('name')]).iris('color', data[$(this).attr('name')]);//trigger('color_changed')
			}
		});
		
	}
	
	/**
	 * Preset functions 
	 */
	$('body').on('click', '.epkb-preset-button', function(){
		let data = $(this).data('colors');
		
		if ($(this).closest('#epkb-wsb-step-3-panel').length) {
			// Main page presets 
			
			epkb_try_set_colors_on_panel( 
				data,
				$('.epkb-wizard-colors-content')
			);
		}
	});
	
	/**
	 * Accordion for the options 
	 */
	$('body').on('click', '.epkb-accordion .epkb-wizard-option-heading', function(){
		let wrap = $(this).closest('.epkb-accordion');
		let currentItem = $(this).closest('.epkb-accordion-body-content');
		let isCurrentActive = currentItem.hasClass('active');

		wrap.find('.epkb-accordion-body-content').removeClass('active');
		
		if (!isCurrentActive) {
			currentItem.addClass('active');
			
		/*scrolling to the top:	setTimeout(function(){
				$("html, body").animate({ scrollTop: currentItem.offset().top - 50 }, 200);
			}, 200); */
		}
		
	});

	$('body').on('click', '#eckb-wizard-main-page-preview a, .epkb-wizard-theme-panel-container a, #eckb-wizard-article-page-preview a', false);


	/********************************************************************
	 *                      Article TOC
	 ********************************************************************/
	var articleContent = $('#eckb-article-content-body');
	var articleToc     = $('.eckb-article-toc');
	if (articleToc.length) {

		if ( !articleToc.data('min') ) {
			articleToc.data('min', 1);
		}

		if ( !articleToc.data('offset') ) {
			articleToc.data('offset', 50);
		}


		let firstLevel = articleToc.data('min');
		let searchStr = 'h' + firstLevel;
		let params = {'scrollOffset' : articleToc.data('offset')};

		while ( firstLevel < 6 ) {
			firstLevel++;
			searchStr += ', h' + firstLevel;
		}

		// return object with headers and their ids
		function getArticleHeaders() {
			let headers = [];

			articleContent.find(searchStr).each(function(){

				let tid;
				let header = {};

				if ($(this).prop('id')) {
					tid = $(this).prop('id');
				} else {
					tid = 'articleTOC_' + headers.length;
					$(this).prop('id', tid);
				}

				header.id = tid;
				header.title = $(this).text();

				if ('H1' == $(this).prop("tagName")) {
					header.level = 1;
				} else if ('H2' == $(this).prop("tagName")) {
					header.level = 2;
				} else if ('H3' == $(this).prop("tagName")) {
					header.level = 3;
				} else if ('H4' == $(this).prop("tagName")) {
					header.level = 4;
				} else if ('H5' == $(this).prop("tagName")) {
					header.level = 5;
				} else if ('H6' == $(this).prop("tagName")) {
					header.level = 6;
				}

				headers.push(header);

			});

			if ( headers.length == 0 ) {
				return headers;
			}

			// find max and min header level
			let maxH = 1;
			let minH = 6;

			headers.forEach(function(header){
				if (header.level > maxH) {
					maxH = header.level
				}

				if (header.level < minH) {
					minH = header.level
				}
			});

			// move down all levels to have 1 lowest
			if ( minH > 1 ) {
				headers.forEach(function(header, i){
					headers[i].level = header.level - minH + 1;
				});
			}

			// now we have levels started from 1 but maybe some levels do not exist

			// check level exist and decrease if not exist
			let i = 1;

			while (i < maxH) {
				let levelExist = false;
				headers.forEach(function(header){
					if (header.level == i) {
						levelExist = true;
					}
				});

				if (levelExist) {
					// all right, level exist, go to the next
					i++;
				} else {
					// no such levelm move all levels that more than current down and check once more
					headers.forEach(function(header, j){
						if (header.level > i) {
							headers[j].level = header.level - 1;
						}
					});
				}
				i++;
			}

			return headers;
		}

		// return html from headers object
		function getToCHTML(headers) {
			let html;

			if ( articleToc.find('.eckb-article-toc__title').length ) {
				let title = articleToc.find('.eckb-article-toc__title').html();
				html = `
					<div class="eckb-article-toc__inner">
						<div class="eckb-article-toc__title">${title}</div>
						<ul>
					`;
			} else {
				html = `
					<div class="eckb-article-toc__inner">
						<ul>
					`;
			}


			headers.forEach(function(header){
				html += `<li class="eckb-article-toc__level eckb-article-toc__level-${header.level}"><a href="#${header.id}">${header.title}</a></li>`;
			});

			html += `
						</ul>
					</div>
				`;

			return html;
		}

		let articleHeaders = getArticleHeaders();

		// show TOC only if headers preset
		if ( articleHeaders.length > 0 ) {
			articleToc.html(getToCHTML(articleHeaders));
			articleContent.find(searchStr).scrollSpy(params);
			articleToc.fadeIn();
		}
	}
});